oslo-config
===========

An OpenStack library for parsing configuration options from the command
line and configuration files.

Contents
--------

.. toctree::
   :maxdepth: 1

   api/autoindex

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

